@@ -16,7 +16,6 @@ from datetime import datetime
 from decimal import Decimal
 from typing import Any, Dict, List, Set, Type, Union, overload
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from boto3.dynamodb.conditions import ConditionBase
 from botocore.client import ClientMeta
 
@@ -105,6 +104,14 @@ else:
 __all__ = ("DynamoDBClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     BackupInUseException: Type[BotocoreClientError]
     BackupNotFoundException: Type[BotocoreClientError]
